package com.fs.aiSipCall.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.aiSipCall.domain.AiSipCallGateway;
import com.fs.common.core.page.TableDataInfo;

import java.util.List;

/**
 * aiSIP外呼网关Service接口
 * 
 * @author fs
 * @date 2026-03-06
 */
public interface IAiSipCallGatewayService extends IService<AiSipCallGateway>{
    /**
     * 查询aiSIP外呼网关
     * 
     * @param id aiSIP外呼网关主键
     * @return aiSIP外呼网关
     */
    AiSipCallGateway selectAiSipCallGatewayById(Long id);

    /**
     * 查询aiSIP外呼网关列表
     * 
     * @param aiSipCallGateway aiSIP外呼网关
     * @return aiSIP外呼网关集合
     */
    List<AiSipCallGateway> selectAiSipCallGatewayList(AiSipCallGateway aiSipCallGateway);

    /**
     * 新增aiSIP外呼网关
     * 
     * @param aiSipCallGateway aiSIP外呼网关
     * @return 结果
     */
    int insertAiSipCallGateway(AiSipCallGateway aiSipCallGateway);

    /**
     * 修改aiSIP外呼网关
     * 
     * @param aiSipCallGateway aiSIP外呼网关
     * @return 结果
     */
    int updateAiSipCallGateway(AiSipCallGateway aiSipCallGateway);

    /**
     * 批量删除aiSIP外呼网关
     * 
     * @param ids 需要删除的aiSIP外呼网关主键集合
     * @return 结果
     */
    int deleteAiSipCallGatewayByIds(Long[] ids);

    /**
     * 删除aiSIP外呼网关信息
     * 
     * @param id aiSIP外呼网关主键
     * @return 结果
     */
    int deleteAiSipCallGatewayById(Long id);

    TableDataInfo remoteList(AiSipCallGateway aiSipCallGateway);
}
